@@ -1,4 +1,4 @@
-package Module::Faker::Package 0.023;
+package Module::Faker::Package 0.024;
 # ABSTRACT: a faked package in a faked module
 
 use Moose;
@@ -56,6 +56,26 @@ sub _format_block {
   return $string;
 }
 
+sub _format_class {
+  my ($self) = @_;
+
+  my $string = sprintf "class %s%s {\n\n  # Your code here\n\n}\n",
+    $self->name,
+    (defined $self->version ? (q{ } . $self->version) : '');
+
+  return $string;
+}
+
+sub _format_role {
+  my ($self) = @_;
+
+  my $string = sprintf "role %s%s {\n\n  # Your code here\n\n}\n",
+    $self->name,
+    (defined $self->version ? (q{ } . $self->version) : '');
+
+  return $string;
+}
+
 sub as_string {
   my ($self) = @_;
 
@@ -87,7 +107,7 @@ Module::Faker::Package - a faked package in a faked module
 
 =head1 VERSION
 
-version 0.023
+version 0.024
 
 =head1 PERL VERSION
 
